from typing import override
from ludic.attrs import NoAttrs
from ludic.types import AnyChildren
from ludic.components import Component
from ludic.html import svg, path, circle, polyline


class IconBase(Component[AnyChildren, NoAttrs]):
    svg_commands = {
        "path": path,
        "circle": circle,
        "polyline": polyline
    }
    svg_data = {
            "attrs": {},
            "items": []
    }    
    class_name = ""
    

    @override
    def render(self):
        
        if class_name := self.attrs.get("class_", ""):
            self.attrs["class_"] = f"{self.class_name} {class_name}"
        else:
            self.attrs["class_"] = class_name

        return svg(          
          *[self.svg_commands[next(iter(item))](**next(iter(item.values()))) for item in self.svg_data.get("items")],
          **self.svg_data.get("attrs")
        )

from .icons.hand_helping import IconHandHelping
from .icons.underline import IconUnderline
from .icons.file_plus_2 import IconFilePlus2
from .icons.sigma import IconSigma
from .icons.clock_9 import IconClock9
from .icons.triangle_alert import IconTriangleAlert
from .icons.triangle import IconTriangle
from .icons.hand import IconHand
from .icons.search import IconSearch
from .icons.signpost_big import IconSignpostBig
from .icons.volume_2 import IconVolume2
from .icons.hand_heart import IconHandHeart
from .icons.bar_chart_big import IconBarChartBig
from .icons.contact import IconContact
from .icons.beer_off import IconBeerOff
from .icons.send_horizontal import IconSendHorizontal
from .icons.move_down import IconMoveDown
from .icons.clipboard_plus import IconClipboardPlus
from .icons.gamepad_2 import IconGamepad2
from .icons.lasso import IconLasso
from .icons.eraser import IconEraser
from .icons.disc_2 import IconDisc2
from .icons.receipt import IconReceipt
from .icons.bed_single import IconBedSingle
from .icons.wine import IconWine
from .icons.briefcase_medical import IconBriefcaseMedical
from .icons.ice_cream_bowl import IconIceCreamBowl
from .icons.parking_meter import IconParkingMeter
from .icons.file_search import IconFileSearch
from .icons.arrow_down import IconArrowDown
from .icons.figma import IconFigma
from .icons.corner_right_up import IconCornerRightUp
from .icons.file_key import IconFileKey
from .icons.earth import IconEarth
from .icons.chevrons_right import IconChevronsRight
from .icons.beef import IconBeef
from .icons.flashlight import IconFlashlight
from .icons.file_pen import IconFilePen
from .icons.ghost import IconGhost
from .icons.list import IconList
from .icons.cctv import IconCctv
from .icons.text_cursor_input import IconTextCursorInput
from .icons.megaphone import IconMegaphone
from .icons.croissant import IconCroissant
from .icons.toy_brick import IconToyBrick
from .icons.route_off import IconRouteOff
from .icons.message_circle_question import IconMessageCircleQuestion
from .icons.square_arrow_right import IconSquareArrowRight
from .icons.briefcase_business import IconBriefcaseBusiness
from .icons.swiss_franc import IconSwissFranc
from .icons.navigation_2_off import IconNavigation2Off
from .icons.bluetooth_off import IconBluetoothOff
from .icons.bed import IconBed
from .icons.panel_right_close import IconPanelRightClose
from .icons.signal_low import IconSignalLow
from .icons.chevrons_down import IconChevronsDown
from .icons.memory_stick import IconMemoryStick
from .icons.disc_3 import IconDisc3
from .icons.wind import IconWind
from .icons.corner_up_right import IconCornerUpRight
from .icons.clapperboard import IconClapperboard
from .icons.subscript import IconSubscript
from .icons.file_digit import IconFileDigit
from .icons.arrow_big_down_dash import IconArrowBigDownDash
from .icons.grape import IconGrape
from .icons.flip_vertical import IconFlipVertical
from .icons.hdmi_port import IconHdmiPort
from .icons.target import IconTarget
from .icons.user_cog import IconUserCog
from .icons.scissors import IconScissors
from .icons.minimize_2 import IconMinimize2
from .icons.cog import IconCog
from .icons.waypoints import IconWaypoints
from .icons.megaphone_off import IconMegaphoneOff
from .icons.receipt_pound_sterling import IconReceiptPoundSterling
from .icons.crosshair import IconCrosshair
from .icons.align_vertical_distribute_end import IconAlignVerticalDistributeEnd
from .icons.pi import IconPi
from .icons.table_cells_merge import IconTableCellsMerge
from .icons.square_equal import IconSquareEqual
from .icons.file_sliders import IconFileSliders
from .icons.package_open import IconPackageOpen
from .icons.vegan import IconVegan
from .icons.airplay import IconAirplay
from .icons.gallery_thumbnails import IconGalleryThumbnails
from .icons.clock_8 import IconClock8
from .icons.message_circle_warning import IconMessageCircleWarning
from .icons.badge_euro import IconBadgeEuro
from .icons.repeat import IconRepeat
from .icons.circle_user_round import IconCircleUserRound
from .icons.square_chevron_right import IconSquareChevronRight
from .icons.arrow_right_left import IconArrowRightLeft
from .icons.grip import IconGrip
from .icons.luggage import IconLuggage
from .icons.hourglass import IconHourglass
from .icons.file_bar_chart import IconFileBarChart
from .icons.russian_ruble import IconRussianRuble
from .icons.circle_chevron_right import IconCircleChevronRight
from .icons.microwave import IconMicrowave
from .icons.volume_1 import IconVolume1
from .icons.party_popper import IconPartyPopper
from .icons.boxes import IconBoxes
from .icons.file_heart import IconFileHeart
from .icons.reply import IconReply
from .icons.badge_percent import IconBadgePercent
from .icons.square_dashed_kanban import IconSquareDashedKanban
from .icons.sunrise import IconSunrise
from .icons.toggle_right import IconToggleRight
from .icons.bug_off import IconBugOff
from .icons.message_square_share import IconMessageSquareShare
from .icons.beer import IconBeer
from .icons.pointer import IconPointer
from .icons.receipt_indian_rupee import IconReceiptIndianRupee
from .icons.sheet import IconSheet
from .icons.spray_can import IconSprayCan
from .icons.scan_line import IconScanLine
from .icons.circle_check_big import IconCircleCheckBig
from .icons.unfold_vertical import IconUnfoldVertical
from .icons.git_pull_request_draft import IconGitPullRequestDraft
from .icons.layout_list import IconLayoutList
from .icons.umbrella import IconUmbrella
from .icons.user import IconUser
from .icons.list_start import IconListStart
from .icons.scatter_chart import IconScatterChart
from .icons.lasso_select import IconLassoSelect
from .icons.arrow_big_down import IconArrowBigDown
from .icons.iteration_cw import IconIterationCw
from .icons.fullscreen import IconFullscreen
from .icons.message_circle_heart import IconMessageCircleHeart
from .icons.sun_dim import IconSunDim
from .icons.replace_all import IconReplaceAll
from .icons.square_arrow_out_down_left import IconSquareArrowOutDownLeft
from .icons.cannabis import IconCannabis
from .icons.iteration_ccw import IconIterationCcw
from .icons.message_circle_more import IconMessageCircleMore
from .icons.file_minus import IconFileMinus
from .icons.square_power import IconSquarePower
from .icons.square_chevron_up import IconSquareChevronUp
from .icons.align_horizontal_justify_start import IconAlignHorizontalJustifyStart
from .icons.copy_plus import IconCopyPlus
from .icons.timer_off import IconTimerOff
from .icons.folder_check import IconFolderCheck
from .icons.badge_japanese_yen import IconBadgeJapaneseYen
from .icons.arrow_up_from_line import IconArrowUpFromLine
from .icons.flip_vertical_2 import IconFlipVertical2
from .icons.annoyed import IconAnnoyed
from .icons.ligature import IconLigature
from .icons.message_square_warning import IconMessageSquareWarning
from .icons.layout_grid import IconLayoutGrid
from .icons.rocking_chair import IconRockingChair
from .icons.chevrons_up_down import IconChevronsUpDown
from .icons.badge_minus import IconBadgeMinus
from .icons.calendar_off import IconCalendarOff
from .icons.circle import IconCircle
from .icons.air_vent import IconAirVent
from .icons.phone_missed import IconPhoneMissed
from .icons.scale_3d import IconScale3D
from .icons.corner_left_up import IconCornerLeftUp
from .icons.milk import IconMilk
from .icons.clipboard_pen import IconClipboardPen
from .icons.home import IconHome
from .icons.file_up import IconFileUp
from .icons.copyright import IconCopyright
from .icons.picture_in_picture import IconPictureInPicture
from .icons.vault import IconVault
from .icons.circle_power import IconCirclePower
from .icons.mailbox import IconMailbox
from .icons.gitlab import IconGitlab
from .icons.music import IconMusic
from .icons.file_bar_chart_2 import IconFileBarChart2
from .icons.rectangle_ellipsis import IconRectangleEllipsis
from .icons.smartphone import IconSmartphone
from .icons.file_symlink import IconFileSymlink
from .icons.alarm_clock_check import IconAlarmClockCheck
from .icons.candy_off import IconCandyOff
from .icons.circuit_board import IconCircuitBoard
from .icons.folder_tree import IconFolderTree
from .icons.equal import IconEqual
from .icons.recycle import IconRecycle
from .icons.arrow_up_left import IconArrowUpLeft
from .icons.clipboard_type import IconClipboardType
from .icons.library import IconLibrary
from .icons.panel_top_close import IconPanelTopClose
from .icons.file_pie_chart import IconFilePieChart
from .icons.square_arrow_down import IconSquareArrowDown
from .icons.list_plus import IconListPlus
from .icons.chevron_down import IconChevronDown
from .icons.backpack import IconBackpack
from .icons.calendar_check_2 import IconCalendarCheck2
from .icons.heading import IconHeading
from .icons.hexagon import IconHexagon
from .icons.strikethrough import IconStrikethrough
from .icons.calendar_fold import IconCalendarFold
from .icons.message_square_heart import IconMessageSquareHeart
from .icons.bird import IconBird
from .icons.bot_message_square import IconBotMessageSquare
from .icons.sun_medium import IconSunMedium
from .icons.badge_info import IconBadgeInfo
from .icons.shield_plus import IconShieldPlus
from .icons.book_marked import IconBookMarked
from .icons.creative_commons import IconCreativeCommons
from .icons.shirt import IconShirt
from .icons.dock import IconDock
from .icons.signpost import IconSignpost
from .icons.door_closed import IconDoorClosed
from .icons.github import IconGithub
from .icons.fold_horizontal import IconFoldHorizontal
from .icons.nfc import IconNfc
from .icons.clipboard_paste import IconClipboardPaste
from .icons.cone import IconCone
from .icons.cooking_pot import IconCookingPot
from .icons.proportions import IconProportions
from .icons.bring_to_front import IconBringToFront
from .icons.usb import IconUsb
from .icons.separator_vertical import IconSeparatorVertical
from .icons.box_select import IconBoxSelect
from .icons.hard_hat import IconHardHat
from .icons.cake_slice import IconCakeSlice
from .icons.sun_moon import IconSunMoon
from .icons.ticket import IconTicket
from .icons.calendar_plus_2 import IconCalendarPlus2
from .icons.case_lower import IconCaseLower
from .icons.layout_template import IconLayoutTemplate
from .icons.panel_right_open import IconPanelRightOpen
from .icons.brackets import IconBrackets
from .icons.star_off import IconStarOff
from .icons.shrink import IconShrink
from .icons.church import IconChurch
from .icons.circle_percent import IconCirclePercent
from .icons.crop import IconCrop
from .icons.flask_round import IconFlaskRound
from .icons.cookie import IconCookie
from .icons.redo_2 import IconRedo2
from .icons.circle_slash_2 import IconCircleSlash2
from .icons.tag import IconTag
from .icons.book_check import IconBookCheck
from .icons.octagon_pause import IconOctagonPause
from .icons.cup_soda import IconCupSoda
from .icons.option import IconOption
from .icons.sparkle import IconSparkle
from .icons.briefcase import IconBriefcase
from .icons.circle_chevron_down import IconCircleChevronDown
from .icons.presentation import IconPresentation
from .icons.square_sigma import IconSquareSigma
from .icons.rotate_cw import IconRotateCw
from .icons.file_audio import IconFileAudio
from .icons.ellipsis_vertical import IconEllipsisVertical
from .icons.badge_plus import IconBadgePlus
from .icons.screen_share_off import IconScreenShareOff
from .icons.square_play import IconSquarePlay
from .icons.align_horizontal_distribute_end import IconAlignHorizontalDistributeEnd
from .icons.file_clock import IconFileClock
from .icons.calendar_search import IconCalendarSearch
from .icons.image_down import IconImageDown
from .icons.swatch_book import IconSwatchBook
from .icons.radius import IconRadius
from .icons.folder_sync import IconFolderSync
from .icons.panels_top_left import IconPanelsTopLeft
from .icons.headset import IconHeadset
from .icons.circle_equal import IconCircleEqual
from .icons.dessert import IconDessert
from .icons.carrot import IconCarrot
from .icons.receipt_euro import IconReceiptEuro
from .icons.map import IconMap
from .icons.check_check import IconCheckCheck
from .icons.inbox import IconInbox
from .icons.circle_alert import IconCircleAlert
from .icons.align_justify import IconAlignJustify
from .icons.power import IconPower
from .icons.a_large_small import IconALargeSmall
from .icons.tent_tree import IconTentTree
from .icons.database import IconDatabase
from .icons.captions import IconCaptions
from .icons.martini import IconMartini
from .icons.arrow_up_to_line import IconArrowUpToLine
from .icons.monitor_down import IconMonitorDown
from .icons.badge_indian_rupee import IconBadgeIndianRupee
from .icons.camera_off import IconCameraOff
from .icons.fuel import IconFuel
from .icons.satellite_dish import IconSatelliteDish
from .icons.bike import IconBike
from .icons.swords import IconSwords
from .icons.message_square_off import IconMessageSquareOff
from .icons.scan_text import IconScanText
from .icons.arrow_down_z_a import IconArrowDownZA
from .icons.rat import IconRat
from .icons.tornado import IconTornado
from .icons.toggle_left import IconToggleLeft
from .icons.file import IconFile
from .icons.puzzle import IconPuzzle
from .icons.align_vertical_distribute_center import IconAlignVerticalDistributeCenter
from .icons.signal import IconSignal
from .icons.egg_off import IconEggOff
from .icons.arrow_up_1_0 import IconArrowUp10
from .icons.file_audio_2 import IconFileAudio2
from .icons.baseline import IconBaseline
from .icons.vibrate_off import IconVibrateOff
from .icons.glass_water import IconGlassWater
from .icons.brain import IconBrain
from .icons.files import IconFiles
from .icons.torus import IconTorus
from .icons.scan_search import IconScanSearch
from .icons.square_dashed_bottom_code import IconSquareDashedBottomCode
from .icons.message_circle import IconMessageCircle
from .icons.message_square_dot import IconMessageSquareDot
from .icons.receipt_japanese_yen import IconReceiptJapaneseYen
from .icons.voicemail import IconVoicemail
from .icons.messages_square import IconMessagesSquare
from .icons.ship_wheel import IconShipWheel
from .icons.message_square_quote import IconMessageSquareQuote
from .icons.contrast import IconContrast
from .icons.cuboid import IconCuboid
from .icons.alarm_clock_plus import IconAlarmClockPlus
from .icons.monitor_pause import IconMonitorPause
from .icons.file_video_2 import IconFileVideo2
from .icons.archive_x import IconArchiveX
from .icons.terminal import IconTerminal
from .icons.move_diagonal import IconMoveDiagonal
from .icons.file_scan import IconFileScan
from .icons.arrow_up_wide_narrow import IconArrowUpWideNarrow
from .icons.move import IconMove
from .icons.maximize import IconMaximize
from .icons.between_vertical_start import IconBetweenVerticalStart
from .icons.laptop_minimal import IconLaptopMinimal
from .icons.radar import IconRadar
from .icons.sparkles import IconSparkles
from .icons.lock_keyhole import IconLockKeyhole
from .icons.octagon_x import IconOctagonX
from .icons.folder_root import IconFolderRoot
from .icons.chevron_up import IconChevronUp
from .icons.circle_help import IconCircleHelp
from .icons.square_percent import IconSquarePercent
from .icons.haze import IconHaze
from .icons.folder_output import IconFolderOutput
from .icons.folder_symlink import IconFolderSymlink
from .icons.file_badge_2 import IconFileBadge2
from .icons.vibrate import IconVibrate
from .icons.laugh import IconLaugh
from .icons.scan_eye import IconScanEye
from .icons.spade import IconSpade
from .icons.cloud_rain_wind import IconCloudRainWind
from .icons.sliders_vertical import IconSlidersVertical
from .icons.undo_2 import IconUndo2
from .icons.file_video import IconFileVideo
from .icons.step_back import IconStepBack
from .icons.flask_conical_off import IconFlaskConicalOff
from .icons.arrow_down_left import IconArrowDownLeft
from .icons.file_text import IconFileText
from .icons.file_stack import IconFileStack
from .icons.folder_open import IconFolderOpen
from .icons.package_minus import IconPackageMinus
from .icons.droplet import IconDroplet
from .icons.whole_word import IconWholeWord
from .icons.paint_roller import IconPaintRoller
from .icons.zap_off import IconZapOff
from .icons.square_kanban import IconSquareKanban
from .icons.keyboard import IconKeyboard
from .icons.x import IconX
from .icons.chevrons_right_left import IconChevronsRightLeft
from .icons.joystick import IconJoystick
from .icons.cigarette import IconCigarette
from .icons.bath import IconBath
from .icons.bar_chart import IconBarChart
from .icons.qr_code import IconQrCode
from .icons.dot import IconDot
from .icons.ice_cream_cone import IconIceCreamCone
from .icons.languages import IconLanguages
from .icons.ampersands import IconAmpersands
from .icons.arrow_left_from_line import IconArrowLeftFromLine
from .icons.bell_minus import IconBellMinus
from .icons.file_cog import IconFileCog
from .icons.wheat import IconWheat
from .icons.cable_car import IconCableCar
from .icons.arrow_up_narrow_wide import IconArrowUpNarrowWide
from .icons.lock import IconLock
from .icons.dice_2 import IconDice2
from .icons.log_in import IconLogIn
from .icons.squircle import IconSquircle
from .icons.cloud_upload import IconCloudUpload
from .icons.shield_ellipsis import IconShieldEllipsis
from .icons.ban import IconBan
from .icons.smartphone_nfc import IconSmartphoneNfc
from .icons.list_video import IconListVideo
from .icons.text_select import IconTextSelect
from .icons.shopping_bag import IconShoppingBag
from .icons.divide import IconDivide
from .icons.piggy_bank import IconPiggyBank
from .icons.battery_warning import IconBatteryWarning
from .icons.wallet_minimal import IconWalletMinimal
from .icons.circle_dollar_sign import IconCircleDollarSign
from .icons.milk_off import IconMilkOff
from .icons.square_parking import IconSquareParking
from .icons.refresh_ccw_dot import IconRefreshCcwDot
from .icons.tally_2 import IconTally2
from .icons.shell import IconShell
from .icons.repeat_2 import IconRepeat2
from .icons.pilcrow import IconPilcrow
from .icons.circle_dot_dashed import IconCircleDotDashed
from .icons.mail_question import IconMailQuestion
from .icons.cloud_drizzle import IconCloudDrizzle
from .icons.copy_minus import IconCopyMinus
from .icons.spline import IconSpline
from .icons.refresh_cw import IconRefreshCw
from .icons.pen import IconPen
from .icons.plane import IconPlane
from .icons.align_vertical_space_between import IconAlignVerticalSpaceBetween
from .icons.chevron_right import IconChevronRight
from .icons.tally_3 import IconTally3
from .icons.clipboard import IconClipboard
from .icons.equal_not import IconEqualNot
from .icons.package import IconPackage
from .icons.instagram import IconInstagram
from .icons.mail_warning import IconMailWarning
from .icons.euro import IconEuro
from .icons.link import IconLink
from .icons.square_chevron_left import IconSquareChevronLeft
from .icons.globe_lock import IconGlobeLock
from .icons.dice_3 import IconDice3
from .icons.hand_platter import IconHandPlatter
from .icons.video_off import IconVideoOff
from .icons.user_round_plus import IconUserRoundPlus
from .icons.key import IconKey
from .icons.square_activity import IconSquareActivity
from .icons.shrub import IconShrub
from .icons.sailboat import IconSailboat
from .icons.file_x_2 import IconFileX2
from .icons.square_slash import IconSquareSlash
from .icons.brain_cog import IconBrainCog
from .icons.meh import IconMeh
from .icons.sliders_horizontal import IconSlidersHorizontal
from .icons.door_open import IconDoorOpen
from .icons.corner_down_right import IconCornerDownRight
from .icons.beaker import IconBeaker
from .icons.list_todo import IconListTodo
from .icons.cloud_sun import IconCloudSun
from .icons.arrow_right import IconArrowRight
from .icons.store import IconStore
from .icons.antenna import IconAntenna
from .icons.chevron_first import IconChevronFirst
from .icons.wheat_off import IconWheatOff
from .icons.aperture import IconAperture
from .icons.calendar_plus import IconCalendarPlus
from .icons.brush import IconBrush
from .icons.thermometer_snowflake import IconThermometerSnowflake
from .icons.clover import IconClover
from .icons.concierge_bell import IconConciergeBell
from .icons.log_out import IconLogOut
from .icons.unfold_horizontal import IconUnfoldHorizontal
from .icons.file_spreadsheet import IconFileSpreadsheet
from .icons.square_radical import IconSquareRadical
from .icons.circle_play import IconCirclePlay
from .icons.square_arrow_up import IconSquareArrowUp
from .icons.file_code_2 import IconFileCode2
from .icons.telescope import IconTelescope
from .icons.ship import IconShip
from .icons.ear_off import IconEarOff
from .icons.worm import IconWorm
from .icons.wallpaper import IconWallpaper
from .icons.ambulance import IconAmbulance
from .icons.space import IconSpace
from .icons.file_input import IconFileInput
from .icons.bar_chart_2 import IconBarChart2
from .icons.book_dashed import IconBookDashed
from .icons.stretch_vertical import IconStretchVertical
from .icons.calendar_check import IconCalendarCheck
from .icons.diff import IconDiff
from .icons.shower_head import IconShowerHead
from .icons.square_pen import IconSquarePen
from .icons.arrow_down_up import IconArrowDownUp
from .icons.git_pull_request import IconGitPullRequest
from .icons.minimize import IconMinimize
from .icons.group import IconGroup
from .icons.settings import IconSettings
from .icons.cloud_snow import IconCloudSnow
from .icons.notepad_text_dashed import IconNotepadTextDashed
from .icons.calendar_x_2 import IconCalendarX2
from .icons.cassette_tape import IconCassetteTape
from .icons.thumbs_down import IconThumbsDown
from .icons.dice_1 import IconDice1
from .icons.move_down_left import IconMoveDownLeft
from .icons.vote import IconVote
from .icons.type import IconType
from .icons.square_dashed_mouse_pointer import IconSquareDashedMousePointer
from .icons.square_menu import IconSquareMenu
from .icons.mouse_pointer_click import IconMousePointerClick
from .icons.regex import IconRegex
from .icons.square_check_big import IconSquareCheckBig
from .icons.loader_circle import IconLoaderCircle
from .icons.popsicle import IconPopsicle
from .icons.lamp_floor import IconLampFloor
from .icons.utensils import IconUtensils
from .icons.archive import IconArchive
from .icons.bean import IconBean
from .icons.panels_right_bottom import IconPanelsRightBottom
from .icons.message_square_text import IconMessageSquareText
from .icons.refresh_cw_off import IconRefreshCwOff
from .icons.phone_outgoing import IconPhoneOutgoing
from .icons.tally_1 import IconTally1
from .icons.arrow_up_from_dot import IconArrowUpFromDot
from .icons.candy import IconCandy
from .icons.pocket import IconPocket
from .icons.repeat_1 import IconRepeat1
from .icons.magnet import IconMagnet
from .icons.circle_parking import IconCircleParking
from .icons.mail import IconMail
from .icons.school import IconSchool
from .icons.arrow_big_right import IconArrowBigRight
from .icons.shield import IconShield
from .icons.download import IconDownload
from .icons.kanban import IconKanban
from .icons.file_volume import IconFileVolume
from .icons.expand import IconExpand
from .icons.gallery_vertical_end import IconGalleryVerticalEnd
from .icons.file_warning import IconFileWarning
from .icons.disc_album import IconDiscAlbum
from .icons.pin import IconPin
from .icons.arrow_up_a_z import IconArrowUpAZ
from .icons.square_check import IconSquareCheck
from .icons.bar_chart_horizontal_big import IconBarChartHorizontalBig
from .icons.icon_import import IconImport
from .icons.webcam import IconWebcam
from .icons.phone_forwarded import IconPhoneForwarded
from .icons.bell_plus import IconBellPlus
from .icons.square_dot import IconSquareDot
from .icons.corner_right_down import IconCornerRightDown
from .icons.square_divide import IconSquareDivide
from .icons.book_open import IconBookOpen
from .icons.forklift import IconForklift
from .icons.castle import IconCastle
from .icons.area_chart import IconAreaChart
from .icons.orbit import IconOrbit
from .icons.parentheses import IconParentheses
from .icons.projector import IconProjector
from .icons.pilcrow_right import IconPilcrowRight
from .icons.server import IconServer
from .icons.user_round_check import IconUserRoundCheck
from .icons.bolt import IconBolt
from .icons.tv import IconTv
from .icons.message_square_dashed import IconMessageSquareDashed
from .icons.droplets import IconDroplets
from .icons.skip_forward import IconSkipForward
from .icons.archive_restore import IconArchiveRestore
from .icons.volume import IconVolume
from .icons.lamp_wall_up import IconLampWallUp
from .icons.bar_chart_3 import IconBarChart3
from .icons.drumstick import IconDrumstick
from .icons.user_plus import IconUserPlus
from .icons.battery_medium import IconBatteryMedium
from .icons.book_a import IconBookA
from .icons.battery_charging import IconBatteryCharging
from .icons.shapes import IconShapes
from .icons.folders import IconFolders
from .icons.satellite import IconSatellite
from .icons.list_minus import IconListMinus
from .icons.circle_arrow_left import IconCircleArrowLeft
from .icons.bookmark_minus import IconBookmarkMinus
from .icons.heater import IconHeater
from .icons.layers import IconLayers
from .icons.earth_lock import IconEarthLock
from .icons.square_parking_off import IconSquareParkingOff
from .icons.dna import IconDna
from .icons.mouse_off import IconMouseOff
from .icons.file_check_2 import IconFileCheck2
from .icons.slash import IconSlash
from .icons.radio import IconRadio
from .icons.align_center_vertical import IconAlignCenterVertical
from .icons.alarm_clock import IconAlarmClock
from .icons.alarm_clock_off import IconAlarmClockOff
from .icons.book import IconBook
from .icons.keyboard_music import IconKeyboardMusic
from .icons.hotel import IconHotel
from .icons.book_text import IconBookText
from .icons.variable import IconVariable
from .icons.touchpad_off import IconTouchpadOff
from .icons.bitcoin import IconBitcoin
from .icons.message_square_x import IconMessageSquareX
from .icons.car_front import IconCarFront
from .icons.alarm_smoke import IconAlarmSmoke
from .icons.dice_4 import IconDice4
from .icons.skull import IconSkull
from .icons.mail_minus import IconMailMinus
from .icons.bot import IconBot
from .icons.plug import IconPlug
from .icons.shield_x import IconShieldX
from .icons.train_track import IconTrainTrack
from .icons.goal import IconGoal
from .icons.folder_archive import IconFolderArchive
from .icons.signal_high import IconSignalHigh
from .icons.user_minus import IconUserMinus
from .icons.plane_landing import IconPlaneLanding
from .icons.wallet import IconWallet
from .icons.circle_check import IconCircleCheck
from .icons.tally_4 import IconTally4
from .icons.file_image import IconFileImage
from .icons.square_dashed_bottom import IconSquareDashedBottom
from .icons.panel_top_open import IconPanelTopOpen
from .icons.bell import IconBell
from .icons.git_branch import IconGitBranch
from .icons.square_m import IconSquareM
from .icons.coffee import IconCoffee
from .icons.panel_left_dashed import IconPanelLeftDashed
from .icons.code import IconCode
from .icons.rail_symbol import IconRailSymbol
from .icons.circle_divide import IconCircleDivide
from .icons.cake import IconCake
from .icons.spell_check_2 import IconSpellCheck2
from .icons.settings_2 import IconSettings2
from .icons.tally_5 import IconTally5
from .icons.message_circle_dashed import IconMessageCircleDashed
from .icons.cloud_moon_rain import IconCloudMoonRain
from .icons.radio_tower import IconRadioTower
from .icons.thermometer import IconThermometer
from .icons.cast import IconCast
from .icons.milestone import IconMilestone
from .icons.move_3d import IconMove3D
from .icons.flag import IconFlag
from .icons.podcast import IconPodcast
from .icons.git_fork import IconGitFork
from .icons.eye_off import IconEyeOff
from .icons.dice_5 import IconDice5
from .icons.tram_front import IconTramFront
from .icons.battery import IconBattery
from .icons.blinds import IconBlinds
from .icons.arrow_left_to_line import IconArrowLeftToLine
from .icons.newspaper import IconNewspaper
from .icons.clipboard_pen_line import IconClipboardPenLine
from .icons.snowflake import IconSnowflake
from .icons.disc import IconDisc
from .icons.step_forward import IconStepForward
from .icons.bomb import IconBomb
from .icons.piano import IconPiano
from .icons.book_copy import IconBookCopy
from .icons.arrow_up_0_1 import IconArrowUp01
from .icons.database_zap import IconDatabaseZap
from .icons.rotate_3d import IconRotate3D
from .icons.star_half import IconStarHalf
from .icons.switch_camera import IconSwitchCamera
from .icons.image_plus import IconImagePlus
from .icons.pencil_ruler import IconPencilRuler
from .icons.container import IconContainer
from .icons.ruler import IconRuler
from .icons.turtle import IconTurtle
from .icons.frown import IconFrown
from .icons.tree_pine import IconTreePine
from .icons.audio_lines import IconAudioLines
from .icons.circle_slash import IconCircleSlash
from .icons.notebook_text import IconNotebookText
from .icons.layout_dashboard import IconLayoutDashboard
from .icons.file_line_chart import IconFileLineChart
from .icons.cpu import IconCpu
from .icons.align_end_horizontal import IconAlignEndHorizontal
from .icons.flame_kindling import IconFlameKindling
from .icons.clipboard_list import IconClipboardList
from .icons.biohazard import IconBiohazard
from .icons.bar_chart_4 import IconBarChart4
from .icons.folder_x import IconFolderX
from .icons.book_open_check import IconBookOpenCheck
from .icons.list_ordered import IconListOrdered
from .icons.factory import IconFactory
from .icons.bold import IconBold
from .icons.tablets import IconTablets
from .icons.fence import IconFence
from .icons.trophy import IconTrophy
from .icons.hash import IconHash
from .icons.shield_minus import IconShieldMinus
from .icons.link_2_off import IconLink2Off
from .icons.share_2 import IconShare2
from .icons.battery_full import IconBatteryFull
from .icons.plus import IconPlus
from .icons.paintbrush_2 import IconPaintbrush2
from .icons.monitor_stop import IconMonitorStop
from .icons.panel_bottom import IconPanelBottom
from .icons.clipboard_minus import IconClipboardMinus
from .icons.check import IconCheck
from .icons.align_vertical_justify_end import IconAlignVerticalJustifyEnd
from .icons.rabbit import IconRabbit
from .icons.plug_zap import IconPlugZap
from .icons.nut import IconNut
from .icons.mail_plus import IconMailPlus
from .icons.move_down_right import IconMoveDownRight
from .icons.rotate_ccw import IconRotateCcw
from .icons.heart_crack import IconHeartCrack
from .icons.flip_horizontal_2 import IconFlipHorizontal2
from .icons.hard_drive import IconHardDrive
from .icons.between_horizontal_end import IconBetweenHorizontalEnd
from .icons.tent import IconTent
from .icons.hard_drive_download import IconHardDriveDownload
from .icons.circle_fading_plus import IconCircleFadingPlus
from .icons.pen_line import IconPenLine
from .icons.align_vertical_space_around import IconAlignVerticalSpaceAround
from .icons.hospital import IconHospital
from .icons.case_sensitive import IconCaseSensitive
from .icons.focus import IconFocus
from .icons.bluetooth import IconBluetooth
from .icons.align_end_vertical import IconAlignEndVertical
from .icons.pie_chart import IconPieChart
from .icons.square_split_vertical import IconSquareSplitVertical
from .icons.headphones import IconHeadphones
from .icons.table_properties import IconTableProperties
from .icons.git_pull_request_create_arrow import IconGitPullRequestCreateArrow
from .icons.folder_git_2 import IconFolderGit2
from .icons.square_x import IconSquareX
from .icons.square_asterisk import IconSquareAsterisk
from .icons.rss import IconRss
from .icons.table_cells_split import IconTableCellsSplit
from .icons.flower_2 import IconFlower2
from .icons.landmark import IconLandmark
from .icons.wifi import IconWifi
from .icons.corner_up_left import IconCornerUpLeft
from .icons.file_archive import IconFileArchive
from .icons.square_arrow_up_left import IconSquareArrowUpLeft
from .icons.arrow_down_from_line import IconArrowDownFromLine
from .icons.watch import IconWatch
from .icons.square_arrow_down_right import IconSquareArrowDownRight
from .icons.scale import IconScale
from .icons.dice_6 import IconDice6
from .icons.message_square_more import IconMessageSquareMore
from .icons.ampersand import IconAmpersand
from .icons.dna_off import IconDnaOff
from .icons.square_arrow_out_up_right import IconSquareArrowOutUpRight
from .icons.hand_coins import IconHandCoins
from .icons.roller_coaster import IconRollerCoaster
from .icons.monitor_smartphone import IconMonitorSmartphone
from .icons.git_commit_vertical import IconGitCommitVertical
from .icons.info import IconInfo
from .icons.blocks import IconBlocks
from .icons.popcorn import IconPopcorn
from .icons.file_badge import IconFileBadge
from .icons.badge_dollar_sign import IconBadgeDollarSign
from .icons.user_x import IconUserX
from .icons.navigation_off import IconNavigationOff
from .icons.key_square import IconKeySquare
from .icons.ticket_minus import IconTicketMinus
from .icons.dog import IconDog
from .icons.layout_panel_left import IconLayoutPanelLeft
from .icons.fan import IconFan
from .icons.radio_receiver import IconRadioReceiver
from .icons.loader import IconLoader
from .icons.palette import IconPalette
from .icons.pilcrow_left import IconPilcrowLeft
from .icons.circle_arrow_out_down_left import IconCircleArrowOutDownLeft
from .icons.receipt_swiss_franc import IconReceiptSwissFranc
from .icons.package_2 import IconPackage2
from .icons.case_upper import IconCaseUpper
from .icons.refresh_ccw import IconRefreshCcw
from .icons.cloud_fog import IconCloudFog
from .icons.git_branch_plus import IconGitBranchPlus
from .icons.file_x import IconFileX
from .icons.heading_1 import IconHeading1
from .icons.hop import IconHop
from .icons.folder_up import IconFolderUp
from .icons.soup import IconSoup
from .icons.folder_plus import IconFolderPlus
from .icons.badge_russian_ruble import IconBadgeRussianRuble
from .icons.git_merge import IconGitMerge
from .icons.japanese_yen import IconJapaneseYen
from .icons.grip_horizontal import IconGripHorizontal
from .icons.list_x import IconListX
from .icons.shield_half import IconShieldHalf
from .icons.mic import IconMic
from .icons.venetian_mask import IconVenetianMask
from .icons.rainbow import IconRainbow
from .icons.git_pull_request_arrow import IconGitPullRequestArrow
from .icons.copy import IconCopy
from .icons.smile_plus import IconSmilePlus
from .icons.fish import IconFish
from .icons.move_up_left import IconMoveUpLeft
from .icons.list_tree import IconListTree
from .icons.zoom_in import IconZoomIn
from .icons.circle_chevron_up import IconCircleChevronUp
from .icons.circle_arrow_out_down_right import IconCircleArrowOutDownRight
from .icons.square_gantt_chart import IconSquareGanttChart
from .icons.search_check import IconSearchCheck
from .icons.arrow_down_to_line import IconArrowDownToLine
from .icons.glasses import IconGlasses
from .icons.coins import IconCoins
from .icons.align_start_vertical import IconAlignStartVertical
from .icons.arrows_up_from_line import IconArrowsUpFromLine
from .icons.snail import IconSnail
from .icons.library_big import IconLibraryBig
from .icons.bookmark_x import IconBookmarkX
from .icons.book_key import IconBookKey
from .icons.panel_left import IconPanelLeft
from .icons.test_tube_diagonal import IconTestTubeDiagonal
from .icons.square_library import IconSquareLibrary
from .icons.message_circle_off import IconMessageCircleOff
from .icons.square_user_round import IconSquareUserRound
from .icons.wand_sparkles import IconWandSparkles
from .icons.file_type_2 import IconFileType2
from .icons.text_quote import IconTextQuote
from .icons.caravan import IconCaravan
from .icons.badge_cent import IconBadgeCent
from .icons.panel_top_dashed import IconPanelTopDashed
from .icons.notebook_tabs import IconNotebookTabs
from .icons.text import IconText
from .icons.test_tubes import IconTestTubes
from .icons.fire_extinguisher import IconFireExtinguisher
from .icons.egg_fried import IconEggFried
from .icons.flag_triangle_left import IconFlagTriangleLeft
from .icons.align_right import IconAlignRight
from .icons.text_cursor import IconTextCursor
from .icons.image import IconImage
from .icons.panel_bottom_open import IconPanelBottomOpen
from .icons.maximize_2 import IconMaximize2
from .icons.lightbulb import IconLightbulb
from .icons.server_off import IconServerOff
from .icons.arrow_big_left_dash import IconArrowBigLeftDash
from .icons.sunset import IconSunset
from .icons.save import IconSave
from .icons.smile import IconSmile
from .icons.search_code import IconSearchCode
from .icons.lamp import IconLamp
from .icons.siren import IconSiren
from .icons.images import IconImages
from .icons.scan import IconScan
from .icons.navigation import IconNavigation
from .icons.cloud_lightning import IconCloudLightning
from .icons.citrus import IconCitrus
from .icons.message_square_diff import IconMessageSquareDiff
from .icons.bell_electric import IconBellElectric
from .icons.ham import IconHam
from .icons.candlestick_chart import IconCandlestickChart
from .icons.monitor_play import IconMonitorPlay
from .icons.badge_pound_sterling import IconBadgePoundSterling
from .icons.hard_drive_upload import IconHardDriveUpload
from .icons.app_window import IconAppWindow
from .icons.badge import IconBadge
from .icons.theater import IconTheater
from .icons.paperclip import IconPaperclip
from .icons.heading_2 import IconHeading2
from .icons.square_scissors import IconSquareScissors
from .icons.fast_forward import IconFastForward
from .icons.flag_triangle_right import IconFlagTriangleRight
from .icons.calendar_range import IconCalendarRange
from .icons.contact_round import IconContactRound
from .icons.syringe import IconSyringe
from .icons.search_slash import IconSearchSlash
from .icons.file_question import IconFileQuestion
from .icons.bar_chart_horizontal import IconBarChartHorizontal
from .icons.sticker import IconSticker
from .icons.award import IconAward
from .icons.panel_right_dashed import IconPanelRightDashed
from .icons.zoom_out import IconZoomOut
from .icons.square_arrow_out_up_left import IconSquareArrowOutUpLeft
from .icons.box import IconBox
from .icons.thumbs_up import IconThumbsUp
from .icons.superscript import IconSuperscript
from .icons.ticket_percent import IconTicketPercent
from .icons.battery_low import IconBatteryLow
from .icons.touchpad import IconTouchpad
from .icons.speech import IconSpeech
from .icons.percent import IconPercent
from .icons.square_chevron_down import IconSquareChevronDown
from .icons.square import IconSquare
from .icons.crown import IconCrown
from .icons.bluetooth_searching import IconBluetoothSearching
from .icons.timer_reset import IconTimerReset
from .icons.stethoscope import IconStethoscope
from .icons.eclipse import IconEclipse
from .icons.donut import IconDonut
from .icons.candy_cane import IconCandyCane
from .icons.play import IconPlay
from .icons.folder_heart import IconFolderHeart
from .icons.file_check import IconFileCheck
from .icons.leafy_green import IconLeafyGreen
from .icons.tangent import IconTangent
from .icons.book_audio import IconBookAudio
from .icons.table import IconTable
from .icons.split import IconSplit
from .icons.send import IconSend
from .icons.barcode import IconBarcode
from .icons.videotape import IconVideotape
from .icons.scroll import IconScroll
from .icons.phone_call import IconPhoneCall
from .icons.columns_4 import IconColumns4
from .icons.baggage_claim import IconBaggageClaim
from .icons.circle_arrow_out_up_right import IconCircleArrowOutUpRight
from .icons.radiation import IconRadiation
from .icons.speaker import IconSpeaker
from .icons.user_round_search import IconUserRoundSearch
from .icons.undo_dot import IconUndoDot
from .icons.facebook import IconFacebook
from .icons.codesandbox import IconCodesandbox
from .icons.file_down import IconFileDown
from .icons.badge_check import IconBadgeCheck
from .icons.baby import IconBaby
from .icons.smartphone_charging import IconSmartphoneCharging
from .icons.book_plus import IconBookPlus
from .icons.unplug import IconUnplug
from .icons.heading_3 import IconHeading3
from .icons.bluetooth_connected import IconBluetoothConnected
from .icons.camera import IconCamera
from .icons.link_2 import IconLink2
from .icons.printer import IconPrinter
from .icons.list_collapse import IconListCollapse
from .icons.workflow import IconWorkflow
from .icons.trees import IconTrees
from .icons.panel_left_close import IconPanelLeftClose
from .icons.git_graph import IconGitGraph
from .icons.redo import IconRedo
from .icons.captions_off import IconCaptionsOff
from .icons.club import IconClub
from .icons.folder_minus import IconFolderMinus
from .icons.move_diagonal_2 import IconMoveDiagonal2
from .icons.combine import IconCombine
from .icons.arrow_up_right import IconArrowUpRight
from .icons.truck import IconTruck
from .icons.layout_panel_top import IconLayoutPanelTop
from .icons.life_buoy import IconLifeBuoy
from .icons.user_search import IconUserSearch
from .icons.square_user import IconSquareUser
from .icons.table_columns_split import IconTableColumnsSplit
from .icons.between_horizontal_start import IconBetweenHorizontalStart
from .icons.pickaxe import IconPickaxe
from .icons.package_x import IconPackageX
from .icons.pen_tool import IconPenTool
from .icons.alarm_clock_minus import IconAlarmClockMinus
from .icons.panels_left_bottom import IconPanelsLeftBottom
from .icons.circle_gauge import IconCircleGauge
from .icons.folder_cog import IconFolderCog
from .icons.at_sign import IconAtSign
from .icons.rotate_ccw_square import IconRotateCcwSquare
from .icons.circle_arrow_right import IconCircleArrowRight
from .icons.shield_alert import IconShieldAlert
from .icons.map_pin_off import IconMapPinOff
from .icons.list_restart import IconListRestart
from .icons.hand_metal import IconHandMetal
from .icons.egg import IconEgg
from .icons.car_taxi_front import IconCarTaxiFront
from .icons.square_mouse_pointer import IconSquareMousePointer
from .icons.monitor_x import IconMonitorX
from .icons.square_terminal import IconSquareTerminal
from .icons.bus import IconBus
from .icons.file_pen_line import IconFilePenLine
from .icons.book_heart import IconBookHeart
from .icons.infinity import IconInfinity
from .icons.gem import IconGem
from .icons.filter_x import IconFilterX
from .icons.git_compare import IconGitCompare
from .icons.receipt_cent import IconReceiptCent
from .icons.feather import IconFeather
from .icons.webhook_off import IconWebhookOff
from .icons.trash import IconTrash
from .icons.tree_palm import IconTreePalm
from .icons.arrow_down_1_0 import IconArrowDown10
from .icons.database_backup import IconDatabaseBackup
from .icons.armchair import IconArmchair
from .icons.wifi_off import IconWifiOff
from .icons.user_round import IconUserRound
from .icons.ungroup import IconUngroup
from .icons.book_lock import IconBookLock
from .icons.leaf import IconLeaf
from .icons.arrow_down_wide_narrow import IconArrowDownWideNarrow
from .icons.network import IconNetwork
from .icons.file_lock_2 import IconFileLock2
from .icons.app_window_mac import IconAppWindowMac
from .icons.arrow_up_z_a import IconArrowUpZA
from .icons.scan_barcode import IconScanBarcode
from .icons.corner_left_down import IconCornerLeftDown
from .icons.message_square_plus import IconMessageSquarePlus
from .icons.folder_clock import IconFolderClock
from .icons.dollar_sign import IconDollarSign
from .icons.triangle_right import IconTriangleRight
from .icons.indian_rupee import IconIndianRupee
from .icons.construction import IconConstruction
from .icons.circle_plus import IconCirclePlus
from .icons.graduation_cap import IconGraduationCap
from .icons.scan_face import IconScanFace
from .icons.fish_symbol import IconFishSymbol
from .icons.monitor_speaker import IconMonitorSpeaker
from .icons.guitar import IconGuitar
from .icons.star import IconStar
from .icons.lock_keyhole_open import IconLockKeyholeOpen
from .icons.monitor_check import IconMonitorCheck
from .icons.sandwich import IconSandwich
from .icons.chef_hat import IconChefHat
from .icons.heading_6 import IconHeading6
from .icons.cloud_off import IconCloudOff
from .icons.save_all import IconSaveAll
from .icons.sun import IconSun
from .icons.wrench import IconWrench
from .icons.signal_medium import IconSignalMedium
from .icons.grab import IconGrab
from .icons.pyramid import IconPyramid
from .icons.book_minus import IconBookMinus
from .icons.gauge import IconGauge
from .icons.message_square import IconMessageSquare
from .icons.bug_play import IconBugPlay
from .icons.book_x import IconBookX
from .icons.heading_4 import IconHeading4
from .icons.pizza import IconPizza
from .icons.unlink import IconUnlink
from .icons.chevrons_down_up import IconChevronsDownUp
from .icons.bone import IconBone
from .icons.flashlight_off import IconFlashlightOff
from .icons.file_json_2 import IconFileJson2
from .icons.anchor import IconAnchor
from .icons.hammer import IconHammer
from .icons.plug_2 import IconPlug2
from .icons.notebook_pen import IconNotebookPen
from .icons.chevrons_up import IconChevronsUp
from .icons.columns_3 import IconColumns3
from .icons.move_horizontal import IconMoveHorizontal
from .icons.highlighter import IconHighlighter
from .icons.square_arrow_up_right import IconSquareArrowUpRight
from .icons.tablet_smartphone import IconTabletSmartphone
from .icons.circle_stop import IconCircleStop
from .icons.twitch import IconTwitch
from .icons.banana import IconBanana
from .icons.tree_deciduous import IconTreeDeciduous
from .icons.folder_lock import IconFolderLock
from .icons.locate import IconLocate
from .icons.list_music import IconListMusic
from .icons.bug import IconBug
from .icons.panel_top import IconPanelTop
from .icons.message_square_code import IconMessageSquareCode
from .icons.mail_open import IconMailOpen
from .icons.youtube import IconYoutube
from .icons.chevrons_left_right import IconChevronsLeftRight
from .icons.bookmark_plus import IconBookmarkPlus
from .icons.a_arrow_up import IconAArrowUp
from .icons.tower_control import IconTowerControl
from .icons.book_up import IconBookUp
from .icons.pocket_knife import IconPocketKnife
from .icons.shovel import IconShovel
from .icons.compass import IconCompass
from .icons.file_minus_2 import IconFileMinus2
from .icons.align_horizontal_justify_end import IconAlignHorizontalJustifyEnd
from .icons.server_crash import IconServerCrash
from .icons.traffic_cone import IconTrafficCone
from .icons.plane_takeoff import IconPlaneTakeoff
from .icons.folder_kanban import IconFolderKanban
from .icons.mail_search import IconMailSearch
from .icons.image_up import IconImageUp
from .icons.cloud_moon import IconCloudMoon
from .icons.columns_2 import IconColumns2
from .icons.warehouse import IconWarehouse
from .icons.rotate_cw_square import IconRotateCwSquare
from .icons.square_function import IconSquareFunction
from .icons.frame import IconFrame
from .icons.credit_card import IconCreditCard
from .icons.circle_arrow_down import IconCircleArrowDown
from .icons.table_2 import IconTable2
from .icons.file_key_2 import IconFileKey2
from .icons.copyleft import IconCopyleft
from .icons.grid_3x3 import IconGrid3X3
from .icons.tv_2 import IconTv2
from .icons.ticket_x import IconTicketX
from .icons.align_vertical_justify_start import IconAlignVerticalJustifyStart
from .icons.heart_off import IconHeartOff
from .icons.cylinder import IconCylinder
from .icons.computer import IconComputer
from .icons.book_type import IconBookType
from .icons.heading_5 import IconHeading5
from .icons.thermometer_sun import IconThermometerSun
from .icons.badge_help import IconBadgeHelp
from .icons.locate_off import IconLocateOff
from .icons.reply_all import IconReplyAll
from .icons.pencil import IconPencil
from .icons.cloud_rain import IconCloudRain
from .icons.send_to_back import IconSendToBack
from .icons.git_pull_request_closed import IconGitPullRequestClosed
from .icons.arrow_big_right_dash import IconArrowBigRightDash
from .icons.align_vertical_distribute_start import IconAlignVerticalDistributeStart
from .icons.book_down import IconBookDown
from .icons.pound_sterling import IconPoundSterling
from .icons.monitor_up import IconMonitorUp
from .icons.bean_off import IconBeanOff
from .icons.trash_2 import IconTrash2
from .icons.circle_user import IconCircleUser
from .icons.skip_back import IconSkipBack
from .icons.file_plus import IconFilePlus
from .icons.scroll_text import IconScrollText
from .icons.gantt_chart import IconGanttChart
from .icons.diamond import IconDiamond
from .icons.delete import IconDelete
from .icons.command import IconCommand
from .icons.package_check import IconPackageCheck
from .icons.align_center_horizontal import IconAlignCenterHorizontal
from .icons.clock import IconClock
from .icons.bell_ring import IconBellRing
from .icons.remove_formatting import IconRemoveFormatting
from .icons.router import IconRouter
from .icons.footprints import IconFootprints
from .icons.octagon import IconOctagon
from .icons.arrow_big_left import IconArrowBigLeft
from .icons.table_rows_split import IconTableRowsSplit
from .icons.phone import IconPhone
from .icons.circle_x import IconCircleX
from .icons.land_plot import IconLandPlot
from .icons.align_horizontal_justify_center import IconAlignHorizontalJustifyCenter
from .icons.sun_snow import IconSunSnow
from .icons.image_off import IconImageOff
from .icons.umbrella_off import IconUmbrellaOff
from .icons.arrow_down_a_z import IconArrowDownAZ
from .icons.panel_left_open import IconPanelLeftOpen
from .icons.brain_circuit import IconBrainCircuit
from .icons.move_vertical import IconMoveVertical
from .icons.users_round import IconUsersRound
from .icons.salad import IconSalad
from .icons.dumbbell import IconDumbbell
from .icons.tractor import IconTractor
from .icons.waves import IconWaves
from .icons.folder_closed import IconFolderClosed
from .icons.eye import IconEye
from .icons.user_round_cog import IconUserRoundCog
from .icons.indent_increase import IconIndentIncrease
from .icons.badge_alert import IconBadgeAlert
from .icons.server_cog import IconServerCog
from .icons.pipette import IconPipette
from .icons.phone_off import IconPhoneOff
from .icons.flower import IconFlower
from .icons.banknote import IconBanknote
from .icons.sprout import IconSprout
from .icons.brick_wall import IconBrickWall
from .icons.copy_check import IconCopyCheck
from .icons.rectangle_vertical import IconRectangleVertical
from .icons.pill import IconPill
from .icons.codepen import IconCodepen
from .icons.dribbble import IconDribbble
from .icons.message_circle_plus import IconMessageCirclePlus
from .icons.axe import IconAxe
from .icons.square_plus import IconSquarePlus
from .icons.gift import IconGift
from .icons.receipt_russian_ruble import IconReceiptRussianRuble
from .icons.package_plus import IconPackagePlus
from .icons.external_link import IconExternalLink
from .icons.line_chart import IconLineChart
from .icons.currency import IconCurrency
from .icons.wand import IconWand
from .icons.file_music import IconFileMusic
from .icons.car import IconCar
from .icons.zap import IconZap
from .icons.trello import IconTrello
from .icons.list_checks import IconListChecks
from .icons.message_square_reply import IconMessageSquareReply
from .icons.badge_x import IconBadgeX
from .icons.building_2 import IconBuilding2
from .icons.moon_star import IconMoonStar
from .icons.clock_1 import IconClock1
from .icons.cigarette_off import IconCigaretteOff
from .icons.binary import IconBinary
from .icons.chevron_last import IconChevronLast
from .icons.pointer_off import IconPointerOff
from .icons.mouse_pointer_2 import IconMousePointer2
from .icons.package_search import IconPackageSearch
from .icons.mic_off import IconMicOff
from .icons.lamp_desk import IconLampDesk
from .icons.share import IconShare
from .icons.circle_parking_off import IconCircleParkingOff
from .icons.tags import IconTags
from .icons.square_bottom_dashed_scissors import IconSquareBottomDashedScissors
from .icons.album import IconAlbum
from .icons.key_round import IconKeyRound
from .icons.square_code import IconSquareCode
from .icons.folder_search_2 import IconFolderSearch2
from .icons.arrow_up import IconArrowUp
from .icons.circle_arrow_out_up_left import IconCircleArrowOutUpLeft
from .icons.microscope import IconMicroscope
from .icons.test_tube import IconTestTube
from .icons.bell_off import IconBellOff
from .icons.linkedin import IconLinkedin
from .icons.arrow_down_narrow_wide import IconArrowDownNarrowWide
from .icons.clock_3 import IconClock3
from .icons.panel_right import IconPanelRight
from .icons.drum import IconDrum
from .icons.view import IconView
from .icons.music_2 import IconMusic2
from .icons.wrap_text import IconWrapText
from .icons.git_compare_arrows import IconGitCompareArrows
from .icons.calendar_minus import IconCalendarMinus
from .icons.book_image import IconBookImage
from .icons.file_volume_2 import IconFileVolume2
from .icons.user_round_x import IconUserRoundX
from .icons.undo import IconUndo
from .icons.video import IconVideo
from .icons.circle_ellipsis import IconCircleEllipsis
from .icons.activity import IconActivity
from .icons.pencil_line import IconPencilLine
from .icons.person_standing import IconPersonStanding
from .icons.twitter import IconTwitter
from .icons.map_pin import IconMapPin
from .icons.folder_input import IconFolderInput
from .icons.filter import IconFilter
from .icons.lightbulb_off import IconLightbulbOff
from .icons.phone_incoming import IconPhoneIncoming
from .icons.refrigerator import IconRefrigerator
from .icons.italic import IconItalic
from .icons.list_end import IconListEnd
from .icons.handshake import IconHandshake
from .icons.chevrons_left import IconChevronsLeft
from .icons.rows_2 import IconRows2
from .icons.mail_x import IconMailX
from .icons.medal import IconMedal
from .icons.message_circle_code import IconMessageCircleCode
from .icons.calendar import IconCalendar
from .icons.inspection_panel import IconInspectionPanel
from .icons.notepad_text import IconNotepadText
from .icons.message_circle_x import IconMessageCircleX
from .icons.arrow_right_from_line import IconArrowRightFromLine
from .icons.globe import IconGlobe
from .icons.arrow_left import IconArrowLeft
from .icons.paintbrush import IconPaintbrush
from .icons.rows_3 import IconRows3
from .icons.align_center import IconAlignCenter
from .icons.badge_swiss_franc import IconBadgeSwissFranc
from .icons.cross import IconCross
from .icons.square_minus import IconSquareMinus
from .icons.university import IconUniversity
from .icons.route import IconRoute
from .icons.circle_arrow_up import IconCircleArrowUp
from .icons.diameter import IconDiameter
from .icons.pc_case import IconPcCase
from .icons.ellipsis import IconEllipsis
from .icons.calendar_heart import IconCalendarHeart
from .icons.book_headphones import IconBookHeadphones
from .icons.arrow_down_right import IconArrowDownRight
from .icons.file_box import IconFileBox
from .icons.paw_print import IconPawPrint
from .icons.laptop import IconLaptop
from .icons.power_off import IconPowerOff
from .icons.redo_dot import IconRedoDot
from .icons.axis_3d import IconAxis3D
from .icons.arrow_big_up import IconArrowBigUp
from .icons.framer import IconFramer
from .icons.mountain import IconMountain
from .icons.stretch_horizontal import IconStretchHorizontal
from .icons.bell_dot import IconBellDot
from .icons.clipboard_x import IconClipboardX
from .icons.folder_down import IconFolderDown
from .icons.shield_question import IconShieldQuestion
from .icons.panel_bottom_dashed import IconPanelBottomDashed
from .icons.volume_x import IconVolumeX
from .icons.music_3 import IconMusic3
from .icons.copy_slash import IconCopySlash
from .icons.file_code import IconFileCode
from .icons.move_left import IconMoveLeft
from .icons.slack import IconSlack
from .icons.circle_dashed import IconCircleDashed
from .icons.clock_2 import IconClock2
from .icons.user_round_minus import IconUserRoundMinus
from .icons.scissors_line_dashed import IconScissorsLineDashed
from .icons.file_output import IconFileOutput
from .icons.cloud import IconCloud
from .icons.hop_off import IconHopOff
from .icons.clock_11 import IconClock11
from .icons.shuffle import IconShuffle
from .icons.quote import IconQuote
from .icons.anvil import IconAnvil
from .icons.washing_machine import IconWashingMachine
from .icons.grip_vertical import IconGripVertical
from .icons.clock_6 import IconClock6
from .icons.drill import IconDrill
from .icons.plug_zap_2 import IconPlugZap2
from .icons.align_horizontal_distribute_start import IconAlignHorizontalDistributeStart
from .icons.file_type import IconFileType
from .icons.rewind import IconRewind
from .icons.wine_off import IconWineOff
from .icons.upload import IconUpload
from .icons.trending_down import IconTrendingDown
from .icons.bookmark_check import IconBookmarkCheck
from .icons.fold_vertical import IconFoldVertical
from .icons.calendar_x import IconCalendarX
from .icons.pause import IconPause
from .icons.radical import IconRadical
from .icons.arrow_big_up_dash import IconArrowBigUpDash
from .icons.folder_key import IconFolderKey
from .icons.grid_2x2 import IconGrid2X2
from .icons.cloud_hail import IconCloudHail
from .icons.search_x import IconSearchX
from .icons.cloudy import IconCloudy
from .icons.replace import IconReplace
from .icons.forward import IconForward
from .icons.mountain_snow import IconMountainSnow
from .icons.indent_decrease import IconIndentDecrease
from .icons.circle_minus import IconCircleMinus
from .icons.dices import IconDices
from .icons.blend import IconBlend
from .icons.bookmark import IconBookmark
from .icons.braces import IconBraces
from .icons.rocket import IconRocket
from .icons.circle_dot import IconCircleDot
from .icons.move_right import IconMoveRight
from .icons.drama import IconDrama
from .icons.asterisk import IconAsterisk
from .icons.user_check import IconUserCheck
from .icons.calendar_clock import IconCalendarClock
from .icons.fish_off import IconFishOff
from .icons.folder_search import IconFolderSearch
from .icons.folder_pen import IconFolderPen
from .icons.cloud_sun_rain import IconCloudSunRain
from .icons.git_pull_request_create import IconGitPullRequestCreate
from .icons.tablet import IconTablet
from .icons.mail_check import IconMailCheck
from .icons.align_vertical_justify_center import IconAlignVerticalJustifyCenter
from .icons.file_diff import IconFileDiff
from .icons.monitor_dot import IconMonitorDot
from .icons.ticket_slash import IconTicketSlash
from .icons.align_horizontal_space_between import IconAlignHorizontalSpaceBetween
from .icons.webhook import IconWebhook
from .icons.diamond_percent import IconDiamondPercent
from .icons.folder_open_dot import IconFolderOpenDot
from .icons.arrow_left_right import IconArrowLeftRight
from .icons.code_xml import IconCodeXml
from .icons.cloud_download import IconCloudDownload
from .icons.utility_pole import IconUtilityPole
from .icons.signal_zero import IconSignalZero
from .icons.book_up_2 import IconBookUp2
from .icons.monitor_off import IconMonitorOff
from .icons.ear import IconEar
from .icons.spell_check import IconSpellCheck
from .icons.file_terminal import IconFileTerminal
from .icons.flame import IconFlame
from .icons.gallery_horizontal_end import IconGalleryHorizontalEnd
from .icons.nut_off import IconNutOff
from .icons.component import IconComponent
from .icons.circle_off import IconCircleOff
from .icons.file_search_2 import IconFileSearch2
from .icons.align_start_horizontal import IconAlignStartHorizontal
from .icons.locate_fixed import IconLocateFixed
from .icons.lock_open import IconLockOpen
from .icons.atom import IconAtom
from .icons.cat import IconCat
from .icons.cloud_cog import IconCloudCog
from .icons.sword import IconSword
from .icons.square_pilcrow import IconSquarePilcrow
from .icons.squirrel import IconSquirrel
from .icons.menu import IconMenu
from .icons.pin_off import IconPinOff
from .icons.lamp_ceiling import IconLampCeiling
from .icons.folder_dot import IconFolderDot
from .icons.utensils_crossed import IconUtensilsCrossed
from .icons.ratio import IconRatio
from .icons.square_arrow_down_left import IconSquareArrowDownLeft
from .icons.octagon_alert import IconOctagonAlert
from .icons.gallery_vertical import IconGalleryVertical
from .icons.image_minus import IconImageMinus
from .icons.clock_7 import IconClock7
from .icons.arrow_right_to_line import IconArrowRightToLine
from .icons.a_arrow_down import IconAArrowDown
from .icons.merge import IconMerge
from .icons.map_pinned import IconMapPinned
from .icons.square_pi import IconSquarePi
from .icons.align_horizontal_space_around import IconAlignHorizontalSpaceAround
from .icons.chrome import IconChrome
from .icons.sticky_note import IconStickyNote
from .icons.ticket_plus import IconTicketPlus
from .icons.shopping_cart import IconShoppingCart
from .icons.copy_x import IconCopyX
from .icons.calculator import IconCalculator
from .icons.clock_10 import IconClock10
from .icons.train_front_tunnel import IconTrainFrontTunnel
from .icons.clock_12 import IconClock12
from .icons.apple import IconApple
from .icons.circle_chevron_left import IconCircleChevronLeft
from .icons.mouse import IconMouse
from .icons.flask_conical import IconFlaskConical
from .icons.picture_in_picture_2 import IconPictureInPicture2
from .icons.pentagon import IconPentagon
from .icons.shield_check import IconShieldCheck
from .icons.arrow_down_0_1 import IconArrowDown01
from .icons.message_circle_reply import IconMessageCircleReply
from .icons.circle_pause import IconCirclePause
from .icons.mails import IconMails
from .icons.clock_5 import IconClock5
from .icons.rectangle_horizontal import IconRectangleHorizontal
from .icons.shopping_basket import IconShoppingBasket
from .icons.list_filter import IconListFilter
from .icons.receipt_text import IconReceiptText
from .icons.music_4 import IconMusic4
from .icons.book_user import IconBookUser
from .icons.shield_ban import IconShieldBan
from .icons.arrow_down_to_dot import IconArrowDownToDot
from .icons.building import IconBuilding
from .icons.clipboard_copy import IconClipboardCopy
from .icons.angry import IconAngry
from .icons.lollipop import IconLollipop
from .icons.between_vertical_end import IconBetweenVerticalEnd
from .icons.history import IconHistory
from .icons.gavel import IconGavel
from .icons.folder import IconFolder
from .icons.drafting_compass import IconDraftingCompass
from .icons.align_horizontal_distribute_center import IconAlignHorizontalDistributeCenter
from .icons.file_lock import IconFileLock
from .icons.layers_2 import IconLayers2
from .icons.users import IconUsers
from .icons.boom_box import IconBoomBox
from .icons.slice import IconSlice
from .icons.folder_git import IconFolderGit
from .icons.fingerprint import IconFingerprint
from .icons.flag_off import IconFlagOff
from .icons.mic_vocal import IconMicVocal
from .icons.corner_down_left import IconCornerDownLeft
from .icons.file_axis_3d import IconFileAxis3D
from .icons.book_open_text import IconBookOpenText
from .icons.timer import IconTimer
from .icons.gamepad import IconGamepad
from .icons.git_commit_horizontal import IconGitCommitHorizontal
from .icons.monitor import IconMonitor
from .icons.clipboard_check import IconClipboardCheck
from .icons.unlink_2 import IconUnlink2
from .icons.square_arrow_out_down_right import IconSquareArrowOutDownRight
from .icons.minus import IconMinus
from .icons.heart_pulse import IconHeartPulse
from .icons.rows_4 import IconRows4
from .icons.heart_handshake import IconHeartHandshake
from .icons.bed_double import IconBedDouble
from .icons.text_search import IconTextSearch
from .icons.audio_waveform import IconAudioWaveform
from .icons.navigation_2 import IconNavigation2
from .icons.paint_bucket import IconPaintBucket
from .icons.chevron_left import IconChevronLeft
from .icons.move_up import IconMoveUp
from .icons.film import IconFilm
from .icons.moon import IconMoon
from .icons.square_arrow_left import IconSquareArrowLeft
from .icons.panel_bottom_close import IconPanelBottomClose
from .icons.weight import IconWeight
from .icons.shield_off import IconShieldOff
from .icons.layers_3 import IconLayers3
from .icons.scaling import IconScaling
from .icons.cable import IconCable
from .icons.accessibility import IconAccessibility
from .icons.move_up_right import IconMoveUpRight
from .icons.wallet_cards import IconWalletCards
from .icons.bus_front import IconBusFront
from .icons.lamp_wall_down import IconLampWallDown
from .icons.mouse_pointer import IconMousePointer
from .icons.file_json import IconFileJson
from .icons.train_front import IconTrainFront
from .icons.calendar_minus_2 import IconCalendarMinus2
from .icons.ribbon import IconRibbon
from .icons.square_stack import IconSquareStack
from .icons.flip_horizontal import IconFlipHorizontal
from .icons.gallery_horizontal import IconGalleryHorizontal
from .icons.notebook import IconNotebook
from .icons.stamp import IconStamp
from .icons.square_split_horizontal import IconSquareSplitHorizontal
from .icons.arrow_up_down import IconArrowUpDown
from .icons.screen_share import IconScreenShare
from .icons.calendar_days import IconCalendarDays
from .icons.align_left import IconAlignLeft
from .icons.separator_horizontal import IconSeparatorHorizontal
from .icons.ferris_wheel import IconFerrisWheel
from .icons.sofa import IconSofa
from .icons.clock_4 import IconClock4
from .icons.ticket_check import IconTicketCheck
from .icons.cherry import IconCherry
from .icons.heart import IconHeart
from .icons.trending_up import IconTrendingUp



from .. import IconBase


class IconCross(IconBase):
    class_name = "lucide lucide-cross"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M11 2a2 2 0 0 0-2 2v5H4a2 2 0 0 0-2 2v2c0 1.1.9 2 2 2h5v5c0 1.1.9 2 2 2h2a2 2 0 0 0 2-2v-5h5a2 2 0 0 0 2-2v-2a2 2 0 0 0-2-2h-5V4a2 2 0 0 0-2-2h-2z"
            }
        }
    ]
}



from .. import IconBase


class IconBookOpenCheck(IconBase):
    class_name = "lucide lucide-book-open-check"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 3H2v15h7c1.7 0 3 1.3 3 3V7c0-2.2-1.8-4-4-4Z"
            }
        },
        {
            "path": {
                "d": "m16 12 2 2 4-4"
            }
        },
        {
            "path": {
                "d": "M22 6V3h-6c-2.2 0-4 1.8-4 4v14c0-1.7 1.3-3 3-3h7v-2.3"
            }
        }
    ]
}



from .. import IconBase


class IconRepeat(IconBase):
    class_name = "lucide lucide-repeat"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m17 2 4 4-4 4"
            }
        },
        {
            "path": {
                "d": "M3 11v-1a4 4 0 0 1 4-4h14"
            }
        },
        {
            "path": {
                "d": "m7 22-4-4 4-4"
            }
        },
        {
            "path": {
                "d": "M21 13v1a4 4 0 0 1-4 4H3"
            }
        }
    ]
}



from .. import IconBase


class IconSquareArrowOutUpLeft(IconBase):
    class_name = "lucide lucide-square-arrow-out-up-left"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M13 3h6a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-6"
            }
        },
        {
            "path": {
                "d": "m3 3 9 9"
            }
        },
        {
            "path": {
                "d": "M3 9V3h6"
            }
        }
    ]
}



from .. import IconBase


class IconMilestone(IconBase):
    class_name = "lucide lucide-milestone"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M18 6H5a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h13l4-3.5L18 6Z"
            }
        },
        {
            "path": {
                "d": "M12 13v8"
            }
        },
        {
            "path": {
                "d": "M12 3v3"
            }
        }
    ]
}



from .. import IconBase


class IconListMusic(IconBase):
    class_name = "lucide lucide-list-music"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M21 15V6"
            }
        },
        {
            "path": {
                "d": "M18.5 18a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5Z"
            }
        },
        {
            "path": {
                "d": "M12 12H3"
            }
        },
        {
            "path": {
                "d": "M16 6H3"
            }
        },
        {
            "path": {
                "d": "M12 18H3"
            }
        }
    ]
}



from .. import IconBase


class IconShell(IconBase):
    class_name = "lucide lucide-shell"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M14 11a2 2 0 1 1-4 0 4 4 0 0 1 8 0 6 6 0 0 1-12 0 8 8 0 0 1 16 0 10 10 0 1 1-20 0 11.93 11.93 0 0 1 2.42-7.22 2 2 0 1 1 3.16 2.44"
            }
        }
    ]
}



from .. import IconBase


class IconVideoOff(IconBase):
    class_name = "lucide lucide-video-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M10.66 6H14a2 2 0 0 1 2 2v2.34l1 1L22 8v8"
            }
        },
        {
            "path": {
                "d": "M16 16a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h2l10 10Z"
            }
        },
        {
            "line": {
                "x1": "2",
                "x2": "22",
                "y1": "2",
                "y2": "22"
            }
        }
    ]
}



from .. import IconBase


class IconSquareSplitVertical(IconBase):
    class_name = "lucide lucide-square-split-vertical"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M5 8V5c0-1 1-2 2-2h10c1 0 2 1 2 2v3"
            }
        },
        {
            "path": {
                "d": "M19 16v3c0 1-1 2-2 2H7c-1 0-2-1-2-2v-3"
            }
        },
        {
            "line": {
                "x1": "4",
                "x2": "20",
                "y1": "12",
                "y2": "12"
            }
        }
    ]
}



from .. import IconBase


class IconPipette(IconBase):
    class_name = "lucide lucide-pipette"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m2 22 1-1h3l9-9"
            }
        },
        {
            "path": {
                "d": "M3 21v-3l9-9"
            }
        },
        {
            "path": {
                "d": "m15 6 3.4-3.4a2.1 2.1 0 1 1 3 3L18 9l.4.4a2.1 2.1 0 1 1-3 3l-3.8-3.8a2.1 2.1 0 1 1 3-3l.4.4Z"
            }
        }
    ]
}



from .. import IconBase


class IconSaveAll(IconBase):
    class_name = "lucide lucide-save-all"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M6 4a2 2 0 0 1 2-2h10l4 4v10.2a2 2 0 0 1-2 1.8H8a2 2 0 0 1-2-2Z"
            }
        },
        {
            "path": {
                "d": "M10 2v4h6"
            }
        },
        {
            "path": {
                "d": "M18 18v-7h-8v7"
            }
        },
        {
            "path": {
                "d": "M18 22H4a2 2 0 0 1-2-2V6"
            }
        }
    ]
}



from .. import IconBase


class IconArrowUp10(IconBase):
    class_name = "lucide lucide-arrow-up-1-0"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m3 8 4-4 4 4"
            }
        },
        {
            "path": {
                "d": "M7 4v16"
            }
        },
        {
            "path": {
                "d": "M17 10V4h-2"
            }
        },
        {
            "path": {
                "d": "M15 10h4"
            }
        },
        {
            "rect": {
                "x": "15",
                "y": "14",
                "width": "4",
                "height": "6",
                "ry": "2"
            }
        }
    ]
}



from .. import IconBase


class IconEar(IconBase):
    class_name = "lucide lucide-ear"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M6 8.5a6.5 6.5 0 1 1 13 0c0 6-6 6-6 10a3.5 3.5 0 1 1-7 0"
            }
        },
        {
            "path": {
                "d": "M15 8.5a2.5 2.5 0 0 0-5 0v1a2 2 0 1 1 0 4"
            }
        }
    ]
}



from .. import IconBase


class IconIceCreamCone(IconBase):
    class_name = "lucide lucide-ice-cream-cone"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m7 11 4.08 10.35a1 1 0 0 0 1.84 0L17 11"
            }
        },
        {
            "path": {
                "d": "M17 7A5 5 0 0 0 7 7"
            }
        },
        {
            "path": {
                "d": "M17 7a2 2 0 0 1 0 4H7a2 2 0 0 1 0-4"
            }
        }
    ]
}



from .. import IconBase


class IconExpand(IconBase):
    class_name = "lucide lucide-expand"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m21 21-6-6m6 6v-4.8m0 4.8h-4.8"
            }
        },
        {
            "path": {
                "d": "M3 16.2V21m0 0h4.8M3 21l6-6"
            }
        },
        {
            "path": {
                "d": "M21 7.8V3m0 0h-4.8M21 3l-6 6"
            }
        },
        {
            "path": {
                "d": "M3 7.8V3m0 0h4.8M3 3l6 6"
            }
        }
    ]
}



from .. import IconBase


class IconEuro(IconBase):
    class_name = "lucide lucide-euro"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 10h12"
            }
        },
        {
            "path": {
                "d": "M4 14h9"
            }
        },
        {
            "path": {
                "d": "M19 6a7.7 7.7 0 0 0-5.2-2A7.9 7.9 0 0 0 6 12c0 4.4 3.5 8 7.8 8 2 0 3.8-.8 5.2-2"
            }
        }
    ]
}



from .. import IconBase


class IconMicroscope(IconBase):
    class_name = "lucide lucide-microscope"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M6 18h8"
            }
        },
        {
            "path": {
                "d": "M3 22h18"
            }
        },
        {
            "path": {
                "d": "M14 22a7 7 0 1 0 0-14h-1"
            }
        },
        {
            "path": {
                "d": "M9 14h2"
            }
        },
        {
            "path": {
                "d": "M9 12a2 2 0 0 1-2-2V6h6v4a2 2 0 0 1-2 2Z"
            }
        },
        {
            "path": {
                "d": "M12 6V3a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v3"
            }
        }
    ]
}



from .. import IconBase


class IconUnfoldHorizontal(IconBase):
    class_name = "lucide lucide-unfold-horizontal"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M16 12h6"
            }
        },
        {
            "path": {
                "d": "M8 12H2"
            }
        },
        {
            "path": {
                "d": "M12 2v2"
            }
        },
        {
            "path": {
                "d": "M12 8v2"
            }
        },
        {
            "path": {
                "d": "M12 14v2"
            }
        },
        {
            "path": {
                "d": "M12 20v2"
            }
        },
        {
            "path": {
                "d": "m19 15 3-3-3-3"
            }
        },
        {
            "path": {
                "d": "m5 9-3 3 3 3"
            }
        }
    ]
}



from .. import IconBase


class IconFileSymlink(IconBase):
    class_name = "lucide lucide-file-symlink"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m10 18 3-3-3-3"
            }
        },
        {
            "path": {
                "d": "M14 2v4a2 2 0 0 0 2 2h4"
            }
        },
        {
            "path": {
                "d": "M4 11V4a2 2 0 0 1 2-2h9l5 5v13a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h7"
            }
        }
    ]
}



from .. import IconBase


class IconPoundSterling(IconBase):
    class_name = "lucide lucide-pound-sterling"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M18 7c0-5.333-8-5.333-8 0"
            }
        },
        {
            "path": {
                "d": "M10 7v14"
            }
        },
        {
            "path": {
                "d": "M6 21h12"
            }
        },
        {
            "path": {
                "d": "M6 13h10"
            }
        }
    ]
}



from .. import IconBase


class IconLaptop(IconBase):
    class_name = "lucide lucide-laptop"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M20 16V7a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v9m16 0H4m16 0 1.28 2.55a1 1 0 0 1-.9 1.45H3.62a1 1 0 0 1-.9-1.45L4 16"
            }
        }
    ]
}



from .. import IconBase


class IconTouchpadOff(IconBase):
    class_name = "lucide lucide-touchpad-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h16"
            }
        },
        {
            "path": {
                "d": "M2 14h12"
            }
        },
        {
            "path": {
                "d": "M22 14h-2"
            }
        },
        {
            "path": {
                "d": "M12 20v-6"
            }
        },
        {
            "path": {
                "d": "m2 2 20 20"
            }
        },
        {
            "path": {
                "d": "M22 16V6a2 2 0 0 0-2-2H10"
            }
        }
    ]
}



from .. import IconBase


class IconShrink(IconBase):
    class_name = "lucide lucide-shrink"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m15 15 6 6m-6-6v4.8m0-4.8h4.8"
            }
        },
        {
            "path": {
                "d": "M9 19.8V15m0 0H4.2M9 15l-6 6"
            }
        },
        {
            "path": {
                "d": "M15 4.2V9m0 0h4.8M15 9l6-6"
            }
        },
        {
            "path": {
                "d": "M9 4.2V9m0 0H4.2M9 9 3 3"
            }
        }
    ]
}



from .. import IconBase


class IconBookUser(IconBase):
    class_name = "lucide lucide-book-user"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20"
            }
        },
        {
            "circle": {
                "cx": "12",
                "cy": "8",
                "r": "2"
            }
        },
        {
            "path": {
                "d": "M15 13a3 3 0 1 0-6 0"
            }
        }
    ]
}



from .. import IconBase


class IconSquarePen(IconBase):
    class_name = "lucide lucide-square-pen"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-7"
            }
        },
        {
            "path": {
                "d": "M18.375 2.625a2.121 2.121 0 1 1 3 3L12 15l-4 1 1-4Z"
            }
        }
    ]
}
